{
  description = "system";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    home-manager = {
      url = "github:nix-community/home-manager";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    nixos-hardware.url = "github:kekrby/nixos-hardware";
    mac-brcm-fw = {
      url = "path:./mac-brcm-fw";
      flake = false;
    };
    #mms.url = "github:mkaito/nixos-modded-minecraft-servers";
    easymacros.url = "git+https://gitlab.com/obsidianical/easymacros.git";
  };

  outputs = { self, nixpkgs, home-manager, nixos-hardware, mac-brcm-fw, ... }@inputs: {
    nixosConfigurations = {
      monosodium-glutamate-g = nixpkgs.lib.nixosSystem {
        specialArgs = {
          inherit inputs;
        };
        system = "x86_64-linux";
        modules = [
          ./monosodium-glutamate-g/configuration.nix
          home-manager.nixosModules.home-manager {
            home-manager.useGlobalPkgs = true;
            home-manager.useUserPackages = true;
            home-manager.users.jade = { nixosConfig, pkgs, ... }: {
              home.sessionVariables.TZ = nixosConfig.time.timeZone;
              home.stateVersion = "${nixosConfig.system.stateVersion}";
            };
          }
        ];
      };
      potatobook-g = nixpkgs.lib.nixosSystem {
        specialArgs = {
          inherit inputs;
        };
        system = "x86_64-linux";
        modules = [
          "${mac-brcm-fw}"
          ./potatobook-g/configuration.nix
          home-manager.nixosModules.home-manager {
            home-manager.useGlobalPkgs = true;
            home-manager.useUserPackages = true;
            home-manager.users.jade = { nixosConfig, pkgs, ... }: {
              home.sessionVariables.TZ = nixosConfig.time.timeZone;
              home.stateVersion = "${nixosConfig.system.stateVersion}";
            };
          }
          nixos-hardware.nixosModules.apple-t2
        ];
      };
      schrottserver = nixpkgs.lib.nixosSystem {
        specialArgs = {
          inherit inputs;
        };
        system = "x86_64-linux";
        modules = [
          ./schrottserver/configuration.nix
          home-manager.nixosModules.home-manager {
            home-manager.useGlobalPkgs = true;
            home-manager.useUserPackages = true;
            home-manager.users.jade = { nixosConfig, pkgs, ... }: {
              home.sessionVariables.TZ = nixosConfig.time.timeZone;
              home.stateVersion = "${nixosConfig.system.stateVersion}";
            };
          }
        ];
      };
    };
  };
}
